@@ -173,21 +173,21 @@ class RpcExchangerClient:
 
     async def chat_create(self, name: str) -> int:
         self.check_authorized()
-        return await self._rpc.chat.chat_create(name=name)
+        return await self._rpc.chat.create(name=name)
 
     async def chat_get_name(self, id: int) -> str:
         self.check_authorized()
-        return await self._rpc.chat.chat_get_name(id=id)
+        return await self._rpc.chat.get_name(id=id)
 
     async def chat_get_users(self, id: int) -> list[int]:
         self.check_authorized()
-        return await self._rpc.chat.chat_get_users(id=id)
+        return await self._rpc.chat.get_users(id=id)
 
     async def chat_join(self, id: int) -> bool:
         self.check_authorized()
         if id in self._chat_list:
             raise ChatAlreadyJoinedError()
-        if not await self._rpc.chat.chat_join(chat_id=id, user_id=self._uid):
+        if not await self._rpc.chat.join(chat_id=id, user_id=self._uid):
             return False
         log.debug(f"messages:{id}")
         await self._pubsub.subscribe(f"messages:{id}")
@@ -199,7 +199,7 @@ class RpcExchangerClient:
         self.check_authorized()
         if id not in self._chat_list:
             raise ChatNotJoinedError()
-        if not await self._rpc.chat.chat_quit(chat_id=id, user_id=self._uid):
+        if not await self._rpc.chat.quit(chat_id=id, user_id=self._uid):
             return False
         log.debug(f"messages:{id}")
         await self._pubsub.unsubscribe(f"messages:{id}")
@@ -210,7 +210,7 @@ class RpcExchangerClient:
     async def chat_list_somebody_joined(self) -> list[tuple[int, str]]:
         self.check_authorized()
         result: list[tuple[int, str]] = [
-            tuple(i) for i in await self._rpc.chat.chat_list_somebody_joined(id=self._uid)
+            tuple(i) for i in await self._rpc.chat.list_somebody_joined(id=self._uid)
         ]
         async with self._chat_list_lock:
             for value, name in result:
